@@ -14,7 +14,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# Stanislav Sinyagin <ssinyagin@yahoo.com>
+# Stanislav Sinyagin <ssinyagin@k-open.com>
 
 package Torrus::Collector::SNMP_Params;
 use strict;
@@ -47,7 +47,7 @@ my %validatorLeafParams =
                                    '+snmp-privpassword' => undef,
                                    '+snmp-privprotocol' => {
                                        'des'       => undef,
-                                       'aes128cfb' => undef,
+                                       'aes' => undef,
                                        '3desede'   => undef } } },
      'snmp-timeout'       => undef,
      'snmp-retries'       => undef,
