@@ -17,7 +17,6 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# $Id$
 # Jon Nistor <nistor at snickers dot org>
 #
 
@@ -26,6 +25,8 @@
 package Torrus::DevDiscover::Symmetricom;
 
 use strict;
+use warnings;
+
 use Torrus::Log;
 
 
@@ -93,6 +94,7 @@ sub buildConfig
     my $data = $devdetails->data();
 
     $cb->addTemplateApplication($devNode, 'Symmetricom::ntp-stats');
+    return;
 }
 
 1;
