@@ -14,7 +14,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# Stanislav Sinyagin <ssinyagin@yahoo.com>
+# Stanislav Sinyagin <ssinyagin@k-open.com>
 
 package Torrus::Renderer::RRDtool;
 use strict;
@@ -45,7 +45,7 @@ my %mime_type =
      'EPS' => 'application/postscript',
      'PDF' => 'application/pdf');
 
-my @arg_arrays = qw(opts defs bg hwtick hrule hwline line fg);
+my @arg_arrays = qw(opts defs bg hwtick hwline line hrule fg);
 
 
 sub prepare_rrgraph_args
@@ -54,7 +54,10 @@ sub prepare_rrgraph_args
     my $config_tree = shift;
     my $token = shift;
     my $view = shift;
-
+    my $opt = shift;
+    
+    $opt = {} unless defined($opt);
+    
     my $obj = {'args' => {}, 'dname' => 'A'};
 
     foreach my $arrayName ( @arg_arrays )
@@ -151,11 +154,14 @@ sub prepare_rrgraph_args
     }
 
     return(undef) if $obj->{'error'};
-    
-    $self->rrd_make_hrules( $config_tree, $token, $view, $obj );
-    if( not $Torrus::Renderer::ignoreDecorations )
+
+    if( not $opt->{'data_only'} )
     {
-        $self->rrd_make_decorations( $config_tree, $token, $view, $obj );
+        $self->rrd_make_hrules( $config_tree, $token, $view, $obj );
+        if( not $Torrus::Renderer::ignoreDecorations )
+        {
+            $self->rrd_make_decorations( $config_tree, $token, $view, $obj );
+        }
     }
 
     # We're all set
@@ -768,15 +774,18 @@ sub rrd_make_hrules
 
             if( defined( $value ) )
             {
-                my $color =
+                my $style =
                     $config_tree->getParam($view, 'hrule-color-'.$hruleName);
-                $color = $self->mkcolor( $color );
 
+                my $color = $self->mkcolor( $style );
+                my $line = $self->mkline( $style );
+                
                 my $legend =
                     $config_tree->getNodeParam($token,
                                                'hrule-legend-'.$hruleName);
 
-                my $arg = sprintf( 'HRULE:%e%s', $value, $color );
+                my $arg = sprintf( '%s:%e%s::skipscale',
+                                   $line, $value, $color );
                 if( defined( $legend ) and $legend =~ /\S/ )
                 {
                     $arg .= ':' . $legend . '\l';
@@ -1288,7 +1297,8 @@ sub mkcolor
     my $self = shift;
     my $color = shift;
 
-    my $recursionLimit = 100;
+    my $alpha;    
+    my $recursionLimit = 10;
 
     while( $color =~ /^\#\#(\S+)$/ )
     {
@@ -1306,9 +1316,19 @@ sub mkcolor
                 Error('No color is defined for ' . $colorName);
                 $color = '#000000';
             }
+
+            my $new_alpha =
+                $Torrus::Renderer::graphStyles{$colorName}{'alpha'};
+            if( defined($new_alpha) )
+            {
+                $alpha = $new_alpha;
+            }
         }
     }
-    return $color;
+
+    $alpha = '' unless defined($alpha);
+    
+    return ($color . $alpha);
 }
 
 sub mkline
