@@ -15,7 +15,7 @@
 #  along with this program; if not, write to the Free Software
 #  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307, USA.
 
-# Stanislav Sinyagin <ssinyagin@yahoo.com>
+# Stanislav Sinyagin <ssinyagin@k-open.com>
 #
 #
 
@@ -79,6 +79,6 @@ JSON
 
 =head1 AUTHOR
 
-Stanislav Sinyagin E<lt>F<ssinyagin@yahoo.com>E<gt>
+Stanislav Sinyagin E<lt>F<ssinyagin@k-open.com>E<gt>
 
 =cut
